@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,10 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import logging
-
 from django.core import urlresolvers
-from django.http import HttpResponse
 from django.utils.translation import ugettext_lazy as _  # noqa
 
 from horizon import tables
@@ -25,8 +20,6 @@ from horizon import tables
 from monitoring.alarmdefs import constants
 from monitoring import api
 
-LOG = logging.getLogger(__name__)
-
 
 class CreateAlarm(tables.LinkAction):
     name = "create_alarm"
@@ -51,8 +44,7 @@ class EditAlarm(tables.LinkAction):
 
     def get_link_url(self, datum):
         return urlresolvers.reverse(constants.URL_PREFIX + 'alarm_edit',
-                                    args=(
-                                          datum['id'], ))
+                                    args=(datum['id'], ))
 
     def allowed(self, request, datum=None):
         return True
@@ -102,4 +94,4 @@ class AlarmsTable(tables.DataTable):
         table_actions = (CreateAlarm,
                          AlarmsFilterAction,
                          DeleteAlarm,
-                        )
+                         )
