@@ -100,13 +100,15 @@ class SetAlarmDefinitionAction(workflows.Action):
     def clean(self):
         cleaned_data = super(SetAlarmDefinitionAction, self).clean()
 
-        alarm_def_name = cleaned_data.get('name', '')
+        alarm_def_name = cleaned_data.get('name', '').strip()
+        if not alarm_def_name:
+            return
         is_name_valid = self._is_alarm_def_name_unique_validator(
             alarm_def_name)
         if not is_name_valid:
             self.add_error('name',
                            _('Alarm definition with %s name already exists')
-                             % alarm_def_name)
+                           % alarm_def_name)
 
     def _is_alarm_def_name_unique_validator(self, value):
         try:
@@ -149,7 +151,7 @@ class SetAlarmDefinitionExpressionAction(workflows.Action):
 
         try:
             self.fields['expression'].metrics = ad_forms._get_metrics(request)
-        except Exception as ex:
+        except Exception:
             exceptions.handle(request, _('Unable to retrieve metrics'))
 
 
